@@ -4,10 +4,12 @@ from nexus.tools.check_for_valid_NexusReader import check_for_valid_NexusReader
 # set isstr in a python 2 vs python 3 safe way
 try:
     basestring  # attempt to evaluate basestring
-    def isstr(s):  # py2
+    # py2
+    def isstr(s):  # pragma: no cover
         return isinstance(s, basestring)
 except NameError:
-    def isstr(s):  # py3
+    # py3
+    def isstr(s):
         return isinstance(s, str)
 
 
@@ -111,7 +113,7 @@ def binarise(nexus_obj, one_nexus_per_block=False, keep_zero=False):
                 new_label = "%s_%d" % (str(label), j)
                 # add to nexus
                 n.add(taxon, new_label, state[j])
-
+            
         if one_nexus_per_block:
             nexuslist.append(n)
             n = NexusWriter()
