@@ -29,12 +29,14 @@ def check_zeros(nexus_obj, absences=None, missing=None):
     """
     check_for_valid_NexusReader(nexus_obj, required_blocks=['data'])
     
-    absences = absences if absences else ['0']
-    missing = missing if missing else ['-', '?']
+    if absences is None:
+        absences = ['0']
+    if missing is None:
+        missing = ['-', '?']
     
     bad = []
-    for site_idx in range(0, nexus_obj.data.nchar):
-        states = Counter([nexus_obj.data.matrix[t][site_idx] for t in nexus_obj.data.matrix])
+    for site_idx, site in enumerate(nexus_obj.data.characters, 0):
+        states = Counter(nexus_obj.data.characters[site].values())
         zeros = sum([
             states[k] for k in states if k in absences or k in missing
         ])
@@ -62,3 +64,4 @@ def remove_zeros(nexus_obj, absences=None, missing=None):
     """
     zeros = check_zeros(nexus_obj, absences=absences, missing=missing)
     return new_nexus_without_sites(nexus_obj, zeros)._convert_to_reader()
+
